From aed342bc1994878ff24701a9f48a63603e44f641 Mon Sep 17 00:00:00 2001
From: Lukas Slebodnik <lslebodn@redhat.com>
Date: Thu, 11 Apr 2013 10:00:14 +0200
Subject: [PATCH 1/2] Fix segmentation fault in test_io.

If configure isn't being run with argument --with-test-dir, then variable
TEST_DIR will be defined, but its value will be empty (""). In this case
opendir will fail with uncatched error "Directory does not exist, or name is
an empty string". Finally function call dirfd will segfault because its
argument is NULL.

I changed default value of TEST_DIR (if --with-test-dir was not used).
Assert to auxiliary function was added and error messages became more verbose.

Function tests_set_cwd does not ignore return value of chdir, because
TEST_DIR should not be the empty string.
---
 src/conf_macros.m4 | 7 ++++---
 src/tests/common.c | 8 ++------
 2 files changed, 6 insertions(+), 9 deletions(-)

diff --git a/src/conf_macros.m4 b/src/conf_macros.m4
index 4ea4e93679563b7c3fdc9af751b1cafd728f859b..26eb4acccc4895e961ecc50d490a3cdd5716d085 100644
--- a/src/conf_macros.m4
+++ b/src/conf_macros.m4
@@ -329,11 +329,12 @@ AC_DEFUN([WITH_TEST_DIR],
                 [AC_HELP_STRING([--with-test-dir=PATH],
                                 [Directory used for make check temporary files [$builddir]]
                                )
-                ]
+                ],
+                [TEST_DIR=$withval],
+                [TEST_DIR="."]
                )
-    TEST_DIR=$with_test_dir
     AC_SUBST(TEST_DIR)
-    AC_DEFINE_UNQUOTED(TEST_DIR, "$with_test_dir", [Directory used for 'make check' temporary files])
+    AC_DEFINE_UNQUOTED(TEST_DIR, "$TEST_DIR", [Directory used for 'make check' temporary files])
   ])
 
 AC_DEFUN([WITH_NSCD],
diff --git a/src/tests/common.c b/src/tests/common.c
index 54c93e281d166e7b55a27a96f5dbc7ce67c57e62..16c051656f86f7b0914893a9349366893429e55f 100644
--- a/src/tests/common.c
+++ b/src/tests/common.c
@@ -33,12 +33,8 @@ tests_set_cwd(void)
 
     ret = chdir(TEST_DIR);
     if (ret == -1) {
-        if (strlen(TEST_DIR)) {
-            fprintf(stderr,
-                    "Could not chdir to [%s].\n"
-                    "Attempting to continue with current dir\n",
-                    TEST_DIR);
-        }
+        fprintf(stderr, "Could not chdir to [%s].\n"
+                "Attempting to continue with current dir\n", TEST_DIR);
     }
 }
 
-- 
1.8.1.4

